<?php
/*
 * === FamilyPicShare v1.3 ===
 * this is "main" index.php
 * 
 * it allows to:
 * 1) upload (also very large) image files (thanks to ImageMagick)
 * 
 * 2) generate 2x kinds of thumbnails:
 * 2.1. the very small (100px width) thumbnails called "imagename.thumbnail.jpg" that are displayed here in index.php overview (sorted by month of upload)
 * 2.2. the larger (1024px width) thumbnails called "imagename.slideshow.jpg" which will be used when user clicks on button "slideshow"
 * 
 * 3) clicking on an image in the month.php view will open/load the full res image :D
 */

// load & init stuff
require_once("config.php"); // also enables/disables in-browser error reporting
require_once("./lib/mail.php");
require_once("./lib/misc.php");
require_once("./lib/thumbnails.imagemagick.php");
require_once("./lib/files_and_folders.php");

// signal if upload 0 = success
// as with the gnu linux standard, any error code that is not 0, is an error code
// 1 = File is not an image
// 2 = Sorry, a file with that filename exists already
// 3 = Sorry, allowed file formats are JPG, JPEG, PNG & GIF
$uploadOk = 1; // if all checkes are passed this will be set to 0

// pictures will be sorted by YYYY-MM uploaded
$date = new DateTime();
$date_dir = date("Y-m"); // "2021-02"
$target_dir = "images/".$date_dir."/";

// if $target_dir does not exist
if(!is_dir($target_dir))
{
    // create it
    mkdir($target_dir, 0755);
}

// if a file was selected
if(array_key_exists("fileToUpload",$_FILES))
{
    $upload_filename = basename($_FILES["fileToUpload"]["name"]);
    $target_file = $target_dir . $upload_filename;

    // process the file to upload
    $uploadOk = 0;
    $imageFileType = strtolower(pathinfo($target_file,PATHINFO_EXTENSION));
    
    // Check if image file is a actual image or fake image
    if(isset($_POST["submit"])) {
      $check = getimagesize($_FILES["fileToUpload"]["tmp_name"]);
      if($check !== false) {
        echo "File is an image - " . $check["mime"] . ".";
        $uploadOk = 0;
      } else {
        echo "File is not an image.";
        $uploadOk = 1;
      }
    }
    
    // Check if file already exists
    if(file_exists($target_file)) {
      echo "Sorry, datei existiert bereits.";
      $uploadOk = 2;
    }
    
    // Check file size
    /*
    if($_FILES["fileToUpload"]["size"] > 500000) {
      echo "Sorry, your file is too large.";
      $uploadOk = 0;
    }
    */
    
    // Allow certain file formats
    if($imageFileType != "jpg" && $imageFileType != "png" && $imageFileType != "jpeg" && $imageFileType != "gif" )
    {
        echo "Sorry, es sind nur die Formate JPG, JPEG, PNG & GIF erlaubt.";
        $uploadOk = 3;
    }

    // Check if $uploadOk is set to 0 by an error
    if($uploadOk > 0)
    {
        echo "Sorry, beim Upload trat ein Fehler auf.";
    }
    else
    {
      // if everything is ok, try to upload file
      if(move_uploaded_file($_FILES["fileToUpload"]["tmp_name"], $target_file))
      {
        echo htmlspecialchars( basename( $_FILES["fileToUpload"]["name"])). " upload erfolgreich! :)";
        $MailText = '
        Hallo,
        <br>
        ein neues Bild wurde auf FamilyPicShare.de hochgeladen.
        <br>
        Direkter Link zum neuen Bild: <a href="https://FamilyPicShare.de/'.$target_file.'">https://FamilyPicShare.de/'.$target_file.'</a>
        <br>
        Have a Good Day
        <br>
        Sharing is Caring :)
        ';
        
        echo sendMail($from, $to, $MailText,"FamilyPicShare.de - ein neues Bild wurde hochgeladen :)");
      }
      else
      {
        echo "Sorry, beim Upload trat ein Fehler auf.";
      }
    }
}
?> 
<!DOCTYPE html>
<html>
	<head>
		<meta charset="utf-8">
		<meta http-equiv="X-UA-Compatible" content="IE=edge">
		<meta name="viewport" content="width=device-width, initial-scale=1">
		<meta name="description" content="an secure (install .htaccess!!!) independent, self hosting easy to install web based software (no database needed) for easy sharing pictures with family (uploading, categorizing, finding pictures)"/>
		<meta name="keywords" content="share,pictures,family" />

        <link rel="icon" href="favicon.ico"><!-- 32×32 -->
<!--    <link rel="icon" href="/icon.svg" type="image/svg+xml"> -->
        <link rel="apple-touch-icon" href="apple-touch-icon.png"><!-- 180×180 -->
        <link rel="manifest" href="manifest.webmanifest">

        <meta name="msapplication-TileColor" content="#da532c">
        <meta name="theme-color" content="#ffffff">

		<title>share family pictures with privacy & secure & easy</title>
		<!-- external styles -->
		<link href="css/style.css" type="text/css" rel="stylesheet"/>
		<script type="text/javascript" src="js/placeholders.min.js"></script>
	</head>
	<body id="body">
		<div id="parent">
			<div class="centered">
				<div id="headline" class="boxShadows">
					<h1>
                        share family pictures
					</h1>
                    <h3>
                        with privacy & secure & easy
                    </h3>
					<div id="PictureUploadForm">
                        <form action="index.php" method="post" enctype="multipart/form-data">
                          Auswählen:
                          <input type="file" name="fileToUpload" id="fileToUpload">
                          <input type="submit" value="hochladen" name="submit">
                        </form>
					</div>
				</div>
				<div id="content">
                    <div id="main">
							<?php				
                            // iterate over folder images
                            $array_of_dirs = listFolders("./images");
                            foreach($array_of_dirs as $dir)
                            {
                                echo '
                                <a href="month.php?input='.$dir.'">
                                    <div class="element">
                                        <div class="title">'.$dir.'</div>
';
                                        GenerateAndShowThumbnails("./images/".$dir, false);
echo '
                                    </div>
                                </a>
';
                            } 
                            ?>
                        </div>
                    </div>
				</div>
			</div>
		</div>
	</body>
</html>